@@ -6,22 +6,46 @@ reading and writing values in the process memory.
 """
 
 __author__ = "Jean Loui Bernard Silva de Jesus"
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 
 from .process import Process
 from .win32.constants import PROCESS_ALL_ACCESS, PROCESS_VM_OPERATION, PROCESS_VM_READ, PROCESS_VM_WRITE
 from .win32.functions import CloseHandle, GetProcessHandle, ReadProcessMemory, WriteProcessMemory
 
-__all__ = ("OpenProcess", "PROCESS_ALL_ACCESS", "PROCESS_VM_OPERATION", "PROCESS_VM_READ", "PROCESS_VM_WRITE")
+from typing import Optional, Type, Union
+
+__all__ = (
+    "OpenProcess",
+    "PROCESS_ALL_ACCESS",
+    "PROCESS_VM_OPERATION",
+    "PROCESS_VM_READ",
+    "PROCESS_VM_WRITE"
+)
+
 
 class OpenProcess(object):
+    """
+    Class to open a process for reading or writing memory.
+    """
+    def __enter__(self):
+        return self
 
-    def __enter__(self): return self
-
-    def __exit__(self, exc_type, exc_value, exc_traceback): self.close()
-
-    def __init__(self, window_title = None, process_name = None, pid = None, permission = PROCESS_ALL_ACCESS):
+    def __exit__(self, exc_type, exc_value, exc_traceback):
+        self.close()
 
+    def __init__(
+        self,
+        window_title: Optional[str] = None,
+        process_name: Optional[str] = None,
+        pid: Optional[int] = None,
+        permission: int = PROCESS_ALL_ACCESS
+    ):
+        """
+        :param window_title: window title of the target program.
+        :param process_name: name of the target process.
+        :param pid: process ID.
+        :param permission: access mode to the process.
+        """
         # Instantiate the permission argument.
         self.__permission = permission
 
@@ -45,40 +69,45 @@ class OpenProcess(object):
         self.__process_handle = GetProcessHandle(permission, False, self.__process.pid)
 
     def close(self):
-
         """
         Close the process handle.
         """
-
         return CloseHandle(self.__process_handle)
 
-    def read_process_memory(self, address, pytype, bufflength):
-
+    def read_process_memory(
+        self,
+        address: int,
+        pytype: Type,
+        bufflength: int
+    ) -> Union[str, int, float]:
         """
         Return a value from a memory address.
 
-        @param address: Target memory address (ex: 0x006A9EC0).
-        @param type_: Type of the value to be received (str, int or float).
-        @param bufflength: Value size in bytes (1, 2, 4, 8).
+        :param address: target memory address (ex: 0x006A9EC0).
+        :param pytype: type of the value to be received (str, int or float).
+        :param bufflength: value size in bytes (1, 2, 4, 8).
         """
-
-        if not self.__permission in [PROCESS_ALL_ACCESS, PROCESS_VM_READ]:
+        if self.__permission not in [PROCESS_ALL_ACCESS, PROCESS_VM_READ]:
             raise PermissionError("The handle does not have permission to read the process memory.")
 
         return win32.functions.ReadProcessMemory(self.__process_handle, address, pytype, bufflength)
 
-    def write_process_memory(self, address, pytype, bufflength, value):
-
+    def write_process_memory(
+        self,
+        address: int,
+        pytype: Type,
+        bufflength: int,
+        value: Union[str, int, float]
+    ) -> Union[str, int, float]:
         """
         Write a value to a memory address.
 
-        @param address: Target memory address (ex: 0x006A9EC0).
-        @param pytype: Type of value to be written into memory (str, int or float).
-        @param bufflength: Value size in bytes (1, 2, 4, 8).
-        @param value: Value to be written (str, int or float).
+        :param address: target memory address (ex: 0x006A9EC0).
+        :param pytype: type of value to be written into memory (str, int or float).
+        :param bufflength: value size in bytes (1, 2, 4, 8).
+        :param value: value to be written (str, int or float).
         """
-
-        if not self.__permission in [PROCESS_ALL_ACCESS, PROCESS_VM_OPERATION | PROCESS_VM_WRITE]:
+        if self.__permission not in [PROCESS_ALL_ACCESS, PROCESS_VM_OPERATION | PROCESS_VM_WRITE]:
             raise PermissionError("The handle does not have permission to write to the process memory.")
 
         return WriteProcessMemory(self.__process_handle, address, pytype, bufflength, value)
